==> cutemaze_1.2.6.orig.tar.gz: cutemaze-1.2.6/translations/cutemaze_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Não foi possível carregar o jogo anterior. Será iniciado um novo jogo.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 decorrido</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 passos dados</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>Restam %1 de %2 alvos</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausa</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Option</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecione o idioma da aplicação:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma do Sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie esta aplicação para que a alteração do idioma surta efeito.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Novo Jogo</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Caçar e Matar</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Backtracker Recursivo</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pilha</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pilha 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pilha 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pilha 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pilha 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Alvos:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamanho:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Caçar e Matar</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Backtracker Recursivo</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pilha</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pilha 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pilha 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pilha 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pilha 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Pontuações do CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Pontuação</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Passos</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmo</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Parabéns!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>A tua pontuação entrou para a lista dos 10 primeiros.
Por favor introduz o teu nome:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Jogo</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Mostrar onde estive</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Mostrar número de passos tomados</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Mostrar tempo decorrido</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Suavizar movimento</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controlos</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Mover para Cima:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Mover para Baixo:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Mover para a Esquerda:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Mover para a Direita:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Colocar/Tirar Marca:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Selecionar Ficheiro do Tema</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Não foi possível criar a pasta de dados.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Não foi possível copiar o ficheiro do tema.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Questão</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Remover o tema selecionado?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Não foi possível remover o tema selecionado.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation>Mostrar Dica:</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualização</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre o &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jogo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Dica</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Pontuações Máximas</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Aproximar</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>A&amp;fastar</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configurações</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma da Aplicação...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferências...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>S&amp;obre</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Um jogo de labirinto visto de cima</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Direitos de Autor &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lançado sob a licença &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Ícones provenientes do tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Utilizados sob a licença &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> cutemaze_1.3.2.orig.tar.gz: cutemaze-1.3.2/translations/cutemaze_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Não foi possível carregar o jogo anterior. Será iniciado um novo jogo.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 decorrido</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 passos dados</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>Restam %1 de %2 alvos</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausa</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Option</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecione o idioma da aplicação:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma do Sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie esta aplicação para que a alteração do idioma surta efeito.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Novo Jogo</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Caçar e Matar</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Backtracker Recursivo</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pilha</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pilha 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pilha 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pilha 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pilha 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Alvos:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamanho:</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Pontuação</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Passos</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmo</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Parabéns!</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Jogo</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Mostrar onde estive</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Mostrar número de passos tomados</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Mostrar tempo decorrido</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Suavizar movimento</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controlos</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Mover para Cima:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Mover para Baixo:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Mover para a Esquerda:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Mover para a Direita:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Colocar/Tirar Marca:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Selecionar Ficheiro do Tema</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Não foi possível criar a pasta de dados.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Não foi possível copiar o ficheiro do tema.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Questão</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Remover o tema selecionado?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Não foi possível remover o tema selecionado.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation>Mostrar Dica:</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualização</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre o &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jogo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Dica</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Pontuações Máximas</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Aproximar</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>A&amp;fastar</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configurações</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma da Aplicação...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferências...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>S&amp;obre</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Um jogo de labirinto visto de cima</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Direitos de Autor &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lançado sob a licença &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Ícones provenientes do tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Utilizados sob a licença &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
